@@ -14,7 +14,7 @@ Tools for the georeferencing of spatial data.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Rectify_Grid(REF_SOURCE=None, GRID=None, REF_TARGET=None, TARGET_TEMPLATE=None, TARGET_GRID=None, XFIELD=None, YFIELD=None, METHOD=None, ORDER=None, RESAMPLING=None, BYTEWISE=None, DATA_TYPE=None, CRS_STRING=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def Rectify_Grid(REF_SOURCE=None, GRID=None, REF_TARGET=None, TARGET_TEMPLATE=None, TARGET_GRID=None, XFIELD=None, YFIELD=None, METHOD=None, ORDER=None, RESAMPLING=None, BYTEWISE=None, DATA_TYPE=None, CRS_STRING=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
     '''
     Rectify Grid
     ----------
@@ -43,6 +43,7 @@ def Rectify_Grid(REF_SOURCE=None, GRID=None, REF_TARGET=None, TARGET_TEMPLATE=No
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
 
@@ -74,12 +75,13 @@ def Rectify_Grid(REF_SOURCE=None, GRID=None, REF_TARGET=None, TARGET_TEMPLATE=No
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_pj_georeference_1(REF_SOURCE=None, GRID=None, REF_TARGET=None, TARGET_TEMPLATE=None, TARGET_GRID=None, XFIELD=None, YFIELD=None, METHOD=None, ORDER=None, RESAMPLING=None, BYTEWISE=None, DATA_TYPE=None, CRS_STRING=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def run_tool_pj_georeference_1(REF_SOURCE=None, GRID=None, REF_TARGET=None, TARGET_TEMPLATE=None, TARGET_GRID=None, XFIELD=None, YFIELD=None, METHOD=None, ORDER=None, RESAMPLING=None, BYTEWISE=None, DATA_TYPE=None, CRS_STRING=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
     '''
     Rectify Grid
     ----------
@@ -108,6 +110,7 @@ def run_tool_pj_georeference_1(REF_SOURCE=None, GRID=None, REF_TARGET=None, TARG
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
 
@@ -139,6 +142,7 @@ def run_tool_pj_georeference_1(REF_SOURCE=None, GRID=None, REF_TARGET=None, TARG
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         return Tool.Execute(Verbose)
@@ -214,7 +218,7 @@ def run_tool_pj_georeference_2(REF_SOURCE=None, INPUT=None, REF_TARGET=None, OUT
         return Tool.Execute(Verbose)
     return False
 
-def Direct_Georeferencing_of_Airborne_Photographs(INPUT=None, DEM=None, TARGET_TEMPLATE=None, OUTPUT=None, EXTENT=None, DEM_GRIDSYSTEM=None, DEM_DEFAULT=None, CFL=None, PXSIZE=None, X=None, Y=None, Z=None, OMEGA=None, PHI=None, KAPPA=None, KAPPA_OFF=None, ORIENTATION=None, ROW_ORDER=None, RESAMPLING=None, DATA_TYPE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def Direct_Georeferencing_of_Airborne_Photographs(INPUT=None, DEM=None, TARGET_TEMPLATE=None, OUTPUT=None, EXTENT=None, DEM_GRIDSYSTEM=None, DEM_DEFAULT=None, CFL=None, PXSIZE=None, X=None, Y=None, Z=None, OMEGA=None, PHI=None, KAPPA=None, KAPPA_OFF=None, ORIENTATION=None, ROW_ORDER=None, RESAMPLING=None, DATA_TYPE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
     '''
     Direct Georeferencing of Airborne Photographs
     ----------
@@ -250,6 +254,7 @@ def Direct_Georeferencing_of_Airborne_Photographs(INPUT=None, DEM=None, TARGET_T
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
 
@@ -288,12 +293,13 @@ def Direct_Georeferencing_of_Airborne_Photographs(INPUT=None, DEM=None, TARGET_T
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_pj_georeference_4(INPUT=None, DEM=None, TARGET_TEMPLATE=None, OUTPUT=None, EXTENT=None, DEM_GRIDSYSTEM=None, DEM_DEFAULT=None, CFL=None, PXSIZE=None, X=None, Y=None, Z=None, OMEGA=None, PHI=None, KAPPA=None, KAPPA_OFF=None, ORIENTATION=None, ROW_ORDER=None, RESAMPLING=None, DATA_TYPE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def run_tool_pj_georeference_4(INPUT=None, DEM=None, TARGET_TEMPLATE=None, OUTPUT=None, EXTENT=None, DEM_GRIDSYSTEM=None, DEM_DEFAULT=None, CFL=None, PXSIZE=None, X=None, Y=None, Z=None, OMEGA=None, PHI=None, KAPPA=None, KAPPA_OFF=None, ORIENTATION=None, ROW_ORDER=None, RESAMPLING=None, DATA_TYPE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
     '''
     Direct Georeferencing of Airborne Photographs
     ----------
@@ -329,6 +335,7 @@ def run_tool_pj_georeference_4(INPUT=None, DEM=None, TARGET_TEMPLATE=None, OUTPU
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
 
@@ -367,6 +374,7 @@ def run_tool_pj_georeference_4(INPUT=None, DEM=None, TARGET_TEMPLATE=None, OUTPU
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         return Tool.Execute(Verbose)
@@ -544,7 +552,7 @@ def run_tool_pj_georeference_6(EXTENT=None, FILE=None, NX=None, NY=None, CFL=Non
         return Tool.Execute(Verbose)
     return False
 
-def Georeference_with_Coordinate_Grids(GRID_X=None, GRID_Y=None, GRIDS=None, TARGET_TEMPLATE=None, OUTPUT=None, RESAMPLING=None, BYTEWISE=None, KEEP_TYPE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def Georeference_with_Coordinate_Grids(GRID_X=None, GRID_Y=None, GRIDS=None, TARGET_TEMPLATE=None, OUTPUT=None, RESAMPLING=None, BYTEWISE=None, KEEP_TYPE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
     '''
     Georeference with Coordinate Grids
     ----------
@@ -568,6 +576,7 @@ def Georeference_with_Coordinate_Grids(GRID_X=None, GRID_Y=None, GRIDS=None, TAR
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
 
@@ -594,12 +603,13 @@ def Georeference_with_Coordinate_Grids(GRID_X=None, GRID_Y=None, GRIDS=None, TAR
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_pj_georeference_7(GRID_X=None, GRID_Y=None, GRIDS=None, TARGET_TEMPLATE=None, OUTPUT=None, RESAMPLING=None, BYTEWISE=None, KEEP_TYPE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def run_tool_pj_georeference_7(GRID_X=None, GRID_Y=None, GRIDS=None, TARGET_TEMPLATE=None, OUTPUT=None, RESAMPLING=None, BYTEWISE=None, KEEP_TYPE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
     '''
     Georeference with Coordinate Grids
     ----------
@@ -623,6 +633,7 @@ def run_tool_pj_georeference_7(GRID_X=None, GRID_Y=None, GRIDS=None, TARGET_TEMP
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
 
@@ -649,12 +660,13 @@ def run_tool_pj_georeference_7(GRID_X=None, GRID_Y=None, GRIDS=None, TARGET_TEMP
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         return Tool.Execute(Verbose)
     return False
 
-def Rectify_Grid_List(REF_SOURCE=None, GRIDS=None, REF_TARGET=None, TARGET_TEMPLATE=None, TARGET_GRIDS=None, XFIELD=None, YFIELD=None, METHOD=None, ORDER=None, RESAMPLING=None, BYTEWISE=None, DATA_TYPE=None, CRS_STRING=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def Rectify_Grid_List(REF_SOURCE=None, GRIDS=None, REF_TARGET=None, TARGET_TEMPLATE=None, TARGET_GRIDS=None, XFIELD=None, YFIELD=None, METHOD=None, ORDER=None, RESAMPLING=None, BYTEWISE=None, DATA_TYPE=None, CRS_STRING=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
     '''
     Rectify Grid List
     ----------
@@ -683,6 +695,7 @@ def Rectify_Grid_List(REF_SOURCE=None, GRIDS=None, REF_TARGET=None, TARGET_TEMPL
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
 
@@ -714,12 +727,13 @@ def Rectify_Grid_List(REF_SOURCE=None, GRIDS=None, REF_TARGET=None, TARGET_TEMPL
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_pj_georeference_10(REF_SOURCE=None, GRIDS=None, REF_TARGET=None, TARGET_TEMPLATE=None, TARGET_GRIDS=None, XFIELD=None, YFIELD=None, METHOD=None, ORDER=None, RESAMPLING=None, BYTEWISE=None, DATA_TYPE=None, CRS_STRING=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def run_tool_pj_georeference_10(REF_SOURCE=None, GRIDS=None, REF_TARGET=None, TARGET_TEMPLATE=None, TARGET_GRIDS=None, XFIELD=None, YFIELD=None, METHOD=None, ORDER=None, RESAMPLING=None, BYTEWISE=None, DATA_TYPE=None, CRS_STRING=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
     '''
     Rectify Grid List
     ----------
@@ -748,6 +762,7 @@ def run_tool_pj_georeference_10(REF_SOURCE=None, GRIDS=None, REF_TARGET=None, TA
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
 
@@ -779,6 +794,7 @@ def run_tool_pj_georeference_10(REF_SOURCE=None, GRIDS=None, REF_TARGET=None, TA
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         return Tool.Execute(Verbose)
