@@ -825,7 +825,7 @@ void CWKSP_Grids::_LUT_Create(void)
 	}
 
 	//-----------------------------------------------------
-	PROGRESSBAR_Set_Position(0);
+	PROGRESSBAR_Set_Ready();
 
 	if( Classes.Get_Count() > 0 )
 	{
